# -*- coding: utf-8 -*-
"""
fonzie Django application initialization.
"""

from __future__ import absolute_import, unicode_literals

from django.apps import AppConfig


class FonzieConfig(AppConfig):
    """Configuration for the fonzie Django application."""

    name = "fonzie"
